.. _about:

About
=====

Questions & feedback
--------------------

SPECIES is developed by Tomas Stolker (tomas.stolker@phys.ethz.ch). Feel free to send an email for questions, comments, and suggestions.

Attribution
-----------

Please cite Stolker et al. in prep. whenever results from SPECIES are used in a publication. Please also make sure to give credit the relevant papers regarding the use of the publicly available data that SPECIES is using, such as the photometric libraries, spectral libraries, atmospheric models, filter transmission curves, photometry of individual objects, etc. More details will follow.